@@ -25,7 +25,7 @@ OsdManager::OsdManager(QObject *parent)
     : QObject(parent)
     , m_cleanupTimer(new QTimer(this))
 {
-    qmlRegisterUncreatableType<KScreen::OsdAction>("org.kde.KScreen", 1, 0, "OsdAction", QStringLiteral("Can't create OsdAction"));
+    qmlRegisterUncreatableMetaObject(OsdAction::staticMetaObject, "org.kde.KScreen", 1, 0, "OsdAction", QStringLiteral("Can't create OsdAction"));
     new OsdServiceAdaptor(this);
 
     // free up memory when the osd hasn't been used for more than 1 minute
@@ -55,10 +55,8 @@ OsdManager::~OsdManager()
 {
 }
 
-OsdAction::Action OsdManager::showActionSelector()
+void OsdManager::showActionSelector()
 {
-    setDelayedReply(true);
-
     connect(new KScreen::GetConfigOperation(), &KScreen::GetConfigOperation::finished, this, [this](const KScreen::ConfigOperation *op) {
         if (op->hasError()) {
             qWarning() << op->errorString();
@@ -114,9 +112,7 @@ OsdAction::Action OsdManager::showActionSelector()
         osd->showActionSelector();
         m_cleanupTimer->start();
     });
-    return OsdAction::NoAction;
 }
-
 }
 
 #include "moc_osdmanager.cpp"
